# KBDD: a knowledge-based and data-driven method for genetic network construction

Updated: February 14 2024

This repository contains code to reproduce the results of simulation and applications in

Chen-Po Liao, Hung-Ching Chang, Chuhsing Kate Hsiao. "KBDD: a knowledge-based and data-driven method for genetic network construction" (2024)
